/// <reference types="lodash" />
import { HTMLAttributes, PropsWithChildren, FC, PureComponent } from 'react';
import { ElementEvent, EChartsType, init } from 'echarts/core';
import { ECBasicOption, ECExtensions, EventHandler, EventHandlerProps } from './utility';
export interface EC<T = {}> extends FC<T> {
    optionOf: (props: PropsWithChildren<T>) => ECBasicOption;
    loadModule?: () => Promise<ECExtensions>;
}
type ContainerProps = PropsWithChildren<Pick<HTMLAttributes<HTMLDivElement>, 'className' | 'style' | 'hidden' | 'tabIndex'>>;
export interface EChartsProps extends ECBasicOption, ContainerProps {
    theme?: string | object;
    initialOptions?: Parameters<typeof init>[2];
}
interface State {
    imported?: boolean;
}
export declare abstract class ECharts extends PureComponent<EChartsProps, State> {
    state: Readonly<State>;
    core?: EChartsType;
    protected eventMap: Partial<Record<ElementEvent['type'], EventHandler[]>>;
    get splittedProps(): {
        container: ContainerProps;
        charts: ECBasicOption;
    };
    resize: import("lodash").DebouncedFunc<() => void>;
    protected boot: (root: HTMLElement | null) => void;
    componentWillUnmount(): void;
    componentDidMount(): Promise<void>;
    protected clearEvents(): void;
    protected dispatchEvents: (handlers: EventHandler[]) => EventHandler;
    protected registerEvents(): void;
    protected pickHandlers(type: string, index: number, props: PropsWithChildren<EventHandlerProps>): import("echarts/types/dist/shared").ECBasicOption;
    componentDidUpdate(): void;
    render(): import("react/jsx-runtime").JSX.Element;
}
export declare class SVGCharts extends ECharts {
    componentDidMount(): Promise<void>;
}
export declare class CanvasCharts extends ECharts {
    componentDidMount(): Promise<void>;
}
export {};
