import type { AxisPointerComponentOption, CalendarComponentOption, GridComponentOption, LegendComponentOption, ParallelComponentOption, SingleAxisComponentOption, TitleComponentOption, ToolboxComponentOption, TooltipComponentOption, VisualMapComponentOption, XAXisComponentOption, YAXisComponentOption } from 'echarts';
import { PropsWithChildren } from 'react';
import { EC } from './charts';
import { EventHandlerProps } from './utility';
export type TitleProps = PropsWithChildren<EventHandlerProps & Omit<TitleComponentOption, 'text'>>;
/**
 * @example
 * ```tsx
 * <Title>Hello, ECharts JSX!</Title>
 * ```
 */
export declare const Title: EC<TitleProps>;
export type ToolboxProps = EventHandlerProps & ToolboxComponentOption;
/**
 * @example
 * ```tsx
 * <Toolbox feature={{ saveAsImage: {} }} />
 * ```
 */
export declare const Toolbox: EC<ToolboxProps>;
export type LegendProps = EventHandlerProps & LegendComponentOption;
/**
 * @example
 * ```tsx
 * <Legend data={['sales']} />
 * ```
 */
export declare const Legend: EC<LegendProps>;
export type VisualMapProps = EventHandlerProps & VisualMapComponentOption;
/**
 * @example
 * ```tsx
 * <VisualMap calculable top="middle" right={10} color={['red', 'yellow']} />
 * ```
 */
export declare const VisualMap: EC<VisualMapProps>;
export type TooltipProps = EventHandlerProps & TooltipComponentOption;
/**
 * @example
 * ```tsx
 * <Tooltip />
 * ```
 */
export declare const Tooltip: EC<TooltipProps>;
export type GridProps = EventHandlerProps & GridComponentOption;
/**
 * @example
 * ```tsx
 * <Grid left="10%" right="10%" bottom="15%" />
 * ```
 */
export declare const Grid: EC<GridProps>;
export type SingleAxisProps = EventHandlerProps & SingleAxisComponentOption;
export declare const SingleAxis: EC<SingleAxisProps>;
export type ParallelAxisProps = EventHandlerProps & ParallelComponentOption;
/**
 * @example
 * ```tsx
 * <ParallelAxis dim={0} name="Price" />
 * <ParallelAxis dim={1} name="Net Weight" />
 * <ParallelAxis dim={2} name="Amount" />
 * ```
 */
export declare const ParallelAxis: EC<ParallelAxisProps>;
export type XAxisProps = EventHandlerProps & XAXisComponentOption;
/**
 * @example
 * ```tsx
 * <XAxis
 *     data={['Shirts', 'Cardigans', 'Chiffons', 'Pants', 'Heels', 'Socks']}
 * />
 * ```
 */
export declare const XAxis: EC<XAxisProps>;
export type YAxisProps = EventHandlerProps & YAXisComponentOption;
/**
 * @example
 * ```tsx
 * <YAxis />
 * ```
 */
export declare const YAxis: EC<YAxisProps>;
export type AxisPointerProps = EventHandlerProps & AxisPointerComponentOption;
/**
 * @example
 * ```tsx
 * <AxisPointer link={[{ xAxisIndex: 'all' }]} />
 * ```
 */
export declare const AxisPointer: EC<AxisPointerProps>;
export type CalendarProps = EventHandlerProps & CalendarComponentOption;
/**
 * @example
 * ```tsx
 * <Calendar
 *     cellSize={['auto', 13]}
 *     range="2016"
 *     yearLabel={{ show: false }}
 * />
 * ```
 */
export declare const Calendar: EC<CalendarProps>;
